class DynamicRemain(object):
    def __init__(self,key,trade_no):
        self.key = key
        self.trade_no = trade_no

    # 业务秘钥
    key = ""
    # 业务编号
    trade_no = ""
    # 代理列表
    proxy = ""